# YAWL - Yet Another Workload
[
![Checks](https://img.shields.io/github/checks-status/gbieul/yawl/master)
![Checks](https://github.com/gbieul/yawl/actions/workflows/yawl-checks.yml/badge.svg)
![Build](https://github.com/gbieul/yawl/actions/workflows/yawl-build.yml/badge.svg)
![License](https://img.shields.io/github/license/gbieul/flake8-markdown.svg)
](https://pypi.org/project/flake8-markdown/)

## 1.0. Intro

## 2.0. Installing YAWL

## 3.0. Using YAWL
    